# twitter-mimic-bot

first run:

```
./bootstrap.sh
```

before working:

```
. activate.sh
```

to develop:

```
pip install --editable .
```

outdated:

```
python3 setup.py develop
```

to run:

```
mimicbot
```
